summaryrefslogtreecommitdiffstats
path: root/src/net/80211/wpa.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/net/80211/wpa.c')
-rw-r--r--src/net/80211/wpa.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/src/net/80211/wpa.c b/src/net/80211/wpa.c
index 1484d0e8..17c11b8e 100644
--- a/src/net/80211/wpa.c
+++ b/src/net/80211/wpa.c
@@ -761,13 +761,14 @@ static int wpa_handle_1_of_2 ( struct wpa_common_ctx *ctx,
/**
* Handle receipt of EAPOL-Key frame for WPA
*
* @v iob I/O buffer
* @v netdev Network device
* @v ll_source Source link-layer address
*/
-static int eapol_key_rx ( struct io_buffer *iob, struct net_device *netdev,
- const void *ll_source )
+static int eapol_key_rx ( struct eapol_supplicant *supplicant,
+ struct io_buffer *iob, const void *ll_source )
{
+ struct net_device *netdev = supplicant->eap.netdev;
struct net80211_device *dev = net80211_get ( netdev );
struct eapol_header *eapol;
struct eapol_key_pkt *pkt;
@@ -761,13 +761,14 @@ static int wpa_handle_1_of_2 ( struct wpa_common_ctx *ctx,
* Handle receipt of EAPOL-Key frame for WPA
*
- * @v iob I/O buffer
- * @v netdev Network device
- * @v ll_source Source link-layer address
+ * @v supplicant EAPoL supplicant
+ * @v iob I/O buffer
+ * @v ll_source Source link-layer address
*/